==> haskell-regex-compat-tdfa-0.95.1.4-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-6Dc6I5vJ0Y91ELBEIJj7QG
key: regex-compat-tdfa-0.95.1.4-6Dc6I5vJ0Y91ELBEIJj7QG
license: BSD3
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex
abi: 6cb381bfe4798f7292eb03bc5daa9b6c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/regex-compat-tdfa-0.95.1.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-6Dc6I5vJ0Y91ELBEIJj7QG
depends:
    array-0.5.1.1 base-4.9.0.0 regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
    regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-tdfa-0.95.1.4-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-6uPcFboaqIh42pxyQoNVXH
key: regex-compat-tdfa-0.95.1.4-6uPcFboaqIh42pxyQoNVXH
license: BSD3
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex
abi: bb7b785ba8468f5c8295cdd570b54245
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/regex-compat-tdfa-0.95.1.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-6uPcFboaqIh42pxyQoNVXH
depends:
    array-0.5.1.1 base-4.9.0.0 regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
    regex-tdfa-1.2.2-ITZHc3hWBSU2Doba6qXtEU
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
